import React, { Suspense } from "react";
import { Routes, Route } from "react-router-dom";

import { URLs } from "./__data__/urls";
import { ProfilePage, AboutPage } from "./pages";
import { ErrorBoundary } from "./components/error-boundary";

const PageWrapper = ({ children }) => (
  <ErrorBoundary>
    <Suspense fallback={<div>Loading...</div>}>{children}</Suspense>
  </ErrorBoundary>
);

export const Dashboard = () => {
  return (
    <Routes>
      <Route
        path={URLs.about.url}
        element={
          <PageWrapper>
            <AboutPage />
          </PageWrapper>
        }
      />
      {URLs.profile.isOn && (
        <Route
          path={URLs.profile.url}
          element={
            <PageWrapper>
              <ProfilePage />
            </PageWrapper>
          }
        />
      )}

      <Route path="*" element={<div>Not found</div>} />
    </Routes>
  );
};
